@@ -1,7 +1,7 @@
 package Bencher::Formatter::RoundNumbers;
 
-our $DATE = '2016-03-26'; # DATE
-our $VERSION = '0.44'; # VERSION
+our $DATE = '2016-03-30'; # DATE
+our $VERSION = '0.45'; # VERSION
 
 use 5.010001;
 use strict;
@@ -44,8 +44,11 @@ sub munge_result {
                 $fmt, $rit->{vs_slowest});
         }
 
+        # we don't need to round result_size to n significant digits because
+        # they are not time measurement, but we do want to round it when it has
+        # been divided when converting unit to kB, MB, etc.
         for my $col (keys %$rit) {
-            if ($col =~ /^(result_size)$/) {
+            if ($col =~ /^(result_size)$/ && $rit->{$col} != int($rit->{$col})) {
                 $rit->{$col} = sprintf($fmt, $rit->{$col});
             }
         }
@@ -67,7 +70,7 @@ Bencher::Formatter::RoundNumbers - Round numbers (rate, time) to certain signifi
 
 =head1 VERSION
 
-This document describes version 0.44 of Bencher::Formatter::RoundNumbers (from Perl distribution Bencher-Backend), released on 2016-03-26.
+This document describes version 0.45 of Bencher::Formatter::RoundNumbers (from Perl distribution Bencher-Backend), released on 2016-03-30.
 
 =for Pod::Coverage .*
 
